"""
Welcome to aaDoc... by Dilli Babu R < dillir07@outlook.com >
aaDoc is a program or tool if you will, can generate efficient documentation for
Automation Anywhere Code.

This file contains methods that takes input from commandline and generates
documentation for Automation Anywhere code using the comments written by the developers.
This is done by using the various tags in the comments, which makes it possible
for the aaDoc

Note: Tag names are inspired by jsDoc tags at https://jsDoc.app

"""

import os
import re
import time
import argparse
from pprint import pprint as pp
from .tags_module.tags import generate_tags_for_re
from .html_helpers_module.html_helpers import get_html_for_tag, get_base_html, get_param_table_header_html
from .stylesheet_source_module import stylesheet_source

# meta details
__author__ = "Dilli Babu R"
__copyright__ = "Copyright 2020, Dilli Babu R"
__contact__ = "dillir07@outlook.com"
__license__ = "GPL"
__version__ = "1.0"
__email__ = "dillir07@outlook.com"
__status__ = "Development"
__date__ = "2020-05-06"

# used a global variable, as it doesn't make sense to compile regex each time in loop
tag_re = None


def process_file(file_path: str, output_folder_path:str) -> dict:
    """
    Processes given input file by reading the file data
    and then filtering the comments and calling parse_comment_line method
    for each comment. Once all comments are parsed the comment_data will be
    used to create documentation by calling write_html method.
    :param file_path: text file path which needs to be processed
    :param output_folder_path: destination to store the generated documentation output file.
    """

    tags_with_comment_values = []  # init list

    global tag_re  # global variable to avoid re-compiling regex

    with open(file_path, 'r') as txt_file:
        input_file_path_with_extension = txt_file.name
        all_data = txt_file.readlines()

    tags_re_pattern = generate_tags_for_re()  # getting the list of tags
    tag_re = re.compile(tags_re_pattern)

    comments_data = [line for line in all_data if 'Comment:' in line]

    # parsing each comment line
    for comment in comments_data:
        parsed_data_for_current_comment_line = parse_comment_line(comment)
        # adding to tags_with_comment_values if it has value
        if parsed_data_for_current_comment_line is not None:
            tags_with_comment_values.append(
                parsed_data_for_current_comment_line)
    
    # tags_with_comment_values should not be sorted because line_number based sort order won't be in correct order. 1,11,12 like that.
    # tags_with_comment_values = sorted(tags_with_comment_values, key=lambda comment_line: comment_line['line_number'])

    input_file_name = os.path.split(input_file_path_with_extension)[1].lower()
    output_file_path = output_folder_path + "\\" + input_file_name.replace(".txt", ".html")
    write_html(output_file_path, input_file_name.replace(".txt", ""), tags_with_comment_values)
    return {'file_path':file_path, 'file_name':input_file_name, 'no_of_lines':len(all_data), 'no_of_comment_lines':len(comments_data)}


def parse_comment_line(comment_line: str) -> dict:
    """
    Parses one given comment line, identifies line_number, tag and tag value example: 25 Comment: @author Dilli Babu
    R <dillir07@outlook.com> here 25 is line_number, tag is @author, value is Dilli Babu R <dillir07@outlook.com>
    these will be added to comment_data and the same is returned, if comment is empty returns None :param
    comment_line: :return: A dictionary like {'line_number': 25, 'tag': '@author', 'value': 'Dilli Babu R
    <dillir07@outlook.com>'} :raises: TypeError when given comment/input doesn't contain 'Comment:'. Every Automation
    Anywhere Comment will have 'Comment:' in it.
    """
    tags_with_values = []
    if 'Comment:' not in comment_line:
        raise TypeError('Not a comment line')
    else:
        line_number = comment_line.split('\t')[0]
        comment = comment_line.split('\t')[1]

        if '@' in comment:
            matched_tags = tag_re.findall(comment)
            for _ in range(len(matched_tags)):
                match_result = tag_re.search(comment)
                tags_with_values.append({'line_number': line_number, 'tag': match_result.group(),
                                         'value': comment[match_result.end():].strip()})
            return tags_with_values[0] if len(tags_with_values) > 0 else None  # returning first matched tag, expecting one tag per line (block level tags)


def write_html(html_file_path: str, filename: str, tags_with_comment_values: list) -> None:
    """
    Loops over the given list of dictionaries and calls appropriate methods of html_helpers.py
    and writes the received html mark up to output file using file operations.
    Output file will be over written if already present, if not new file will be created.
    :param html_file_path: output file path, should be fully qualified file path
    :param filename: filename of the output file which is same as input file name, used in html title tag
    :param tags_with_comment_values: a list of dictionaries with keys line_number, tag, value
    :return: None
    """
    working_on_param_tag = False
    written_param_count = 0
    with open(html_file_path, 'w') as html:
        html.write(get_base_html(title=filename))
        # looping over list of comments data
        for comment_data in tags_with_comment_values:
            # we are checking this conditions to group the param tags in sequence to write in same table.
            if comment_data['tag'] == '@param':
                written_param_count += 1
                if working_on_param_tag:
                    # no need to write table headers as we already working on param
                    # i.e., table headers will be already written
                    pass
                else:
                    # we just encountered first param, so writing param table headers
                    html.write(get_param_table_header_html())
                    working_on_param_tag = True
            else:  # some other tag, check if we were working on param table and end table if needed
                working_on_param_tag = False
                if written_param_count > 0:
                    # means we were working on param so need to close it
                    html.write('</table></div>')
                    written_param_count = 0  # reset counter
            html.write(get_html_for_tag(comment_data))
        html.write('</body></html>')


def create_index_page(project_name: str, index_html_file_path: str, files_info: list) -> None:
    """
    Creates a index page or (home page) which contains links to other documentation files.
    also contains created date. (this date is documentation created date and is not part of other documentation files)
    :param index_html_file_path: fully qualified file_path to create index file
    :param files_info: list of file info dictionaries 
            {'file_path':file_path, 'file_name':input_file_name, 'no_of_lines':len(all_data), 'no_of_comment_lines':len(comments_data)}
    :return: None
    """
    
    with open(index_html_file_path, "w") as html:
        html.write(get_base_html(project_name))
        html.write(
            '<div><span class="header">' + project_name + ' - Documentation</span></div>')
        # writing creation date
        html.write('<div><span class="label">Created on: </><span>' +
                   str(time.strftime("%b %d, %Y")) + '</span></div>')
        html.write('<div><span class="file">Files:</span></div>')
        for file_info in files_info:
            file_name = file_info['file_name'].lower().replace(".txt", "")
            html.write(
                f'<div><span class="file-link">'
                f'<a href="{file_name}.html" target="_blank" rel="noreferrer">{file_name.capitalize()}</a></span></div>')
            html.write('<br>')
            html.write(f'<div><table><tr><th><span class="label">File Path:</span></th><td><span><a href="file:///{file_info["file_path"]}" target="_blank" rel="noreferrer">{file_info["file_path"]}</a></span></td></tr></table></div>')
            html.write(f'<div><table><tr><th><span class="label">No of Comment lines:</span></th><td><span>{file_info["no_of_comment_lines"]}</span></td></tr></table></div>')
            html.write(f'<div><table><tr><th><span class="label">Total Number of lines:</span></th><td><span>{file_info["no_of_lines"]}</span></td></tr></table></div>')
            html.write('<br><br>')
        html.write('<div class="footer"><p class="footer-content">Documentation auto generated by <a href="https://dillir07.github.io/aadoc/" target="_blank" style="text-decoration:none"><span id="doc"><span id="aa">AA</span>Doc</span></a> tool, by <a class="author" href="mailto:dillir07@outlook.com">Dilli Babu R</a></p></div>')
        html.write('</body></html>')


def create_style_sheet(css_file_path: str) -> None:
    """
    Creates a stylesheet file (.css) which contains style rules for elements used in documentation.
    :param css_file_path: fully qualified path.
    :return: None
    """
    css_source = stylesheet_source.stylesheet_source_data
    with open(css_file_path, 'w') as css:
        css.write(css_source)


def process_inputs(project_name, code_folder_path: str, output_folder_path: str) -> None:
    """
    This function takes input_folder_path which is code_folder_path and output_folder_path which is destination folder
    path for writing output html.
    Then reads the list of text files in the folder and calls process_file method iteratively. Once all the files are
    processed then creates index page by calling create_index_page method and then creates stylesheet by calling
    create_style_sheet method.
    :param code_folder_path: input folder path where .txt files are present.
    :param output_folder_path: destination folder path to write html outputs.
    :return: None
    """

    print('processing files at', code_folder_path)
    files = os.listdir(code_folder_path)
    files_info = []
    text_files = [file for file in files if file.lower().endswith('.txt')]
    if len(text_files) <= 0:
        print('No text files are available in the given folder to process')
        return  # no files to process

    if output_folder_path == '':
        output_folder_path = code_folder_path + "\\" + "output"
    if not os.path.exists(output_folder_path):
        os.makedirs(output_folder_path)

    for text_file in text_files:
        print('processing', text_file)
        file_info = process_file(code_folder_path + '\\' + text_file, output_folder_path)
        files_info.append(file_info)
    create_index_page(project_name, output_folder_path + '\\' + "index.html", files_info)
    create_style_sheet(output_folder_path + '\\' + "styles.css")


def aa_doc() -> None:
    """
    This method bootstraps the arg_parse module and verifies the inputs given by the user via CLI.
    Then calls process_input() method.
    :return: None
    """
    arg_parser = argparse.ArgumentParser(
        description='A tool that generates documentation from Automation Anywhere comments inside code (.txt) files, '
                    'text files can be '
                    'created in Automation Anywhere Client, by going to "File" menu and then selecting "Save as text '
                    'file".',
        epilog='If you require any help, please reach out to me at dillir07@outlook.com')

    arg_parser.add_argument('input_folder_path', metavar=r'"C:\..\code files\input"',
                            type=str, help='folder path in which Automation Anywhere code .txt files are present')
    arg_parser.add_argument('output_folder_path', metavar=r'"C:\..\output"', type=str, nargs='?', default='',
                            help='Destination to store generated documentation files, if not provided an output folder '
                                 'will be created inside input folder.')
    args = arg_parser.parse_args()

    interactive = False

    if interactive:
        project_name = input('Please enter project name')
    else:
        project_name = 'Project'
    
    if project_name.strip() == '':
        project_name = 'Project'
    process_inputs(project_name, args.input_folder_path, args.output_folder_path)


# program execution starts here
# if __name__ == "__main__":
#     aa_doc()



"""
This file is part of aaDoc project. A tool used to generate documentation from Automation Anywhere code.
This file contains code and functions that provides HTML source code to write documentation.
These methods will be called by aadoc.py when appropriate by passing the tag name to get respective html source.
CSS class names will be automatically embedded into html before returning, customization can eb done to the css rules
without making changes to class name here.

We mostly use Template class of python's string module to interpolate the html source strings.

Note: Tags are inspired by jsDoc tags at https://jsDoc.app

"""

from string import Template


def get_author_html(comment_data: dict) -> str:
    """
    Provides html source for author tag i.e., @author
    A hyper link will be created if author value has an email id ('@' symbol) present between '<' and '>'.
    :param comment_data: A dictionary of type {'line_number': line_number, 'tag': '@example',
                        'value': 'author name <email@email.com>'}
    :return: html source for author
    """
    author = comment_data['value']  # assuming whole comment as name if email found truncate
    email = ''

    author_html = Template(
        '<div><table><tr><th><span class="label">Author:</span></th><td><span><a class="author" '
        'href="$email">$author</a></span></tr></table></div>')
    if '<' in comment_data['value'] and '>' in comment_data['value']:
        # email or website is present
        content_in_braces = (comment_data['value'])[
                            comment_data['value'].find('<') + 1:comment_data['value'].find('>')]
        # added mailto link if value contains '@' else place whatever is present (assuming it is a website url)
        email = 'mailto:' + content_in_braces if '@' in content_in_braces else content_in_braces
        author = author[:author.find('<')]

    return author_html.substitute(author=author.strip(), email=email)


def get_file_html(comment_data: dict) -> str:
    """
    Provides html source for file tag
    :param comment_data: A dictionary of type {'line_number':25, 'tag':'@file', value:'some file name'}
    :return: html code
    """
    file_html = Template('<div><span class="file">$file</span></div>')
    return file_html.substitute(file=comment_data['value'])


def get_date_html(comment_data: dict) -> str:
    """
    Provides html source for date tag.
    Note: No date validations or conversions are done.
    whatever value is provided by user's comments the same will come here.
    :param comment_data: A dictionary of type {'line_number':25, 'tag':'@file', value:'some file name'}
    :return: html markup
    """
    date_html = Template(
        '<div><table><tr><th><span class="label">Date:</span></th><td><span>$date</span></td></tr></table></div>')
    return date_html.substitute(date=comment_data['value'])


def get_version_html(comment_data: dict) -> str:
    """
    Provides html source for version tag.
    Note: No version validations or conversions are done.
    :param comment_data: A dictionary of type {'line_number':25, 'tag':'@version', value:'5.4'}
    :return: html markup
    """
    version_html = Template(
        '<div><table><tr><th><span class="label">Version:</span></th><td><span>$version</span></td></tr></table></div>')
    return version_html.substitute(version=comment_data['value'])


def get_since_html(comment_data: dict) -> str:
    """
    Provides html source for since tag.
    Note: No since version validations are done.
    :param comment_data: A dictionary of type {'line_number':25, 'tag':'@since', value:'5.4 - Does something special'}
    :return: html markup
    """
    since_html = Template(
        '<div><table><tr><th><span class="label">Since:</span></th><td><span>$since</span></td></tr></table></div>')
    return since_html.substitute(since=comment_data['value'])


def get_copyright_html(comment_data: dict) -> str:
    """
    Provides html source for copyright tag.
    No copyright symbols or year values are included.
    :param comment_data: A dictionary of type {'line_number':25, 'tag':'@copyright', value:'Dilli Babu R'}
    :return: html markup
    """
    copyright_html = Template(
        '<div><table><tr class="copyright"><th><span '
        'class="label">Copyright:</span></th><td><span>$copyright</span></td></tr></table></div>')
    return copyright_html.substitute(copyright=comment_data['value'])


def get_license_html(comment_data: dict) -> str:
    """
    Provides html source for license tag.
    :param comment_data: A dictionary of type {'line_number':25,
                                        'tag':'@license', value:'GNU General Public License v3.0'} :return: html markup
    :return: html markup
    """
    license_html = Template(
        '<div><table><tr class="license"><th><span '
        'class="label">License:</span></th><td><span>$license</span></td></tr></table></div>')
    return license_html.substitute(license=comment_data['value'])


def get_function_html(comment_data: dict) -> str:
    """
    Provides html source for function tag.
    :param comment_data: A dictionary of type {'line_number':25, 'tag':'@function', value:'get_some_data()'}
    :return: html markup
    """
    function_html = Template('<div><span class="function">$function</span></div>')
    return function_html.substitute(function=comment_data['value'])


def get_requires_html(comment_data: dict) -> str:
    """
    Provides html source for requires tag.
    :param comment_data: A dictionary of type {'line_number':25, 'tag':'@requires', value:'get_some_data()'}
    :return: html markup
    """
    requires_html = Template('<div><span class="requires">$requires</span></div>')
    return requires_html.substitute(requires=comment_data['value'])


def get_description_html(comment_data: dict) -> str:
    """
    Provides html source for description tag.
    :param comment_data: A dictionary of type {'line_number':25, 'tag':'@description',
                                                value:'Some details description about a function or anything'}
    :return: html markup
    """
    description_html = Template('<div><span class="description">$description</span></div>')
    return description_html.substitute(description=comment_data['value'])


def get_param_html(comment_data: dict) -> str:
    """
    Provides html source for param tag.
    Here we will try to fill as much data as possible.
    Typically a param tag will be in for @param {Type} param_name - param description
    if any of them are missing we will try to fill the remaining values, by checking the existence of braces and hyphen.
    :param comment_data: A dictionary of type {'line_number':25, 'tag':'@param', value:'{Integer} count - File counter'}
    :return: html markup
    """
    param_html = Template(
        '<tr><td class="param-table-cell"><span>$name</span></td><td '
        'class="param-table-cell"><span>$type</span></td><td '
        'class="param-table-cell"><span>$description</span></td></tr>')
    type = ''
    name = ''
    description = ''
    if '{' in comment_data['value'] and '}' in comment_data['value']:
        type = (comment_data['value'])[
               comment_data['value'].find('{') + 1:comment_data['value'].find('}')]
        name = (comment_data['value'])[
               comment_data['value'].find('}') + 1:]
    if '-' in comment_data['value']:
        name = name[:name.find('-')]
        description = (comment_data['value'])[
                      comment_data['value'].find('-') + 1:]
    return param_html.safe_substitute(name=name.strip(), type=type.strip(), description=description.strip())


def do_nothing(comment_data: dict) -> None:
    """
    work in progress stuff, just returns readable format of comment data
    :param comment_data: {'line_number':25, 'tag':'@namespace', value:'name space'}
    :return: html mark up
    """
    wip_html = Template('<p class="nothing">$line_number, $tag, $value</p>')
    return wip_html.substitute(line_number=comment_data['line_number'], tag=comment_data['tag'],
                               value=comment_data['value'])


def get_empty_line_html(comment_data: dict) -> str:
    """
    Work in progress
    :param comment_data: {'line_number':25, 'tag':'@emptyline', value:''}
    :return: html mark up
    """
    return '<p>' + comment_data['line_number'] + '</p>'


def get_html_for_tag(comment_data: dict) -> str:
    """
    This method receives call from another files (aaDoc.py) and identifies the tag and call the appropriate function
    based on the tag.
    Note: Work in progress
    :param comment_data: {'line_number':25, 'tag':'@file', value:'file name'}
    :return: str (html markup)
    """
    html = {
        '@author': get_author_html,
        '@date': get_date_html,
        '@constant': do_nothing,
        '@copyright': get_copyright_html,
        '@default': do_nothing,
        '@deprecated': do_nothing,
        '@description': get_description_html,
        '@file': get_file_html,
        '@function': get_function_html,
        '@global': do_nothing,
        '@ignore': do_nothing,
        '@license': get_license_html,
        '@module': do_nothing,
        '@name': do_nothing,
        '@namespace': do_nothing,
        '@package': do_nothing,
        '@param': get_param_html,
        '@requires': get_requires_html,
        '@returns': do_nothing,
        '@see': do_nothing,
        '@since': get_since_html,
        '@summary': do_nothing,
        '@throws': do_nothing,
        '@todo': do_nothing,
        '@type': do_nothing,
        '@version': get_version_html,
        '@emptyline': get_empty_line_html,
    }
    return html[comment_data['tag']](comment_data)


def get_param_table_header_html() -> str:
    """
    This function returns table headers used in creating param table.
    Should not used used for other tables.
    :return: html mark up
    """
    return '<div><span class="property-title">Parameters</span></div><div><table class="param-table"><tr class="param-header-row"><th class="param-table-cell">Name</th><th ' \
           'class="param-table-cell">Type</th><th class="param-table-cell">Description</th></tr> '


def get_base_html(title: str = "Documentation") -> str:
    """
    Returns base html having HTML5 declaration, head tag, title tag and till start of the body tag.
    :param title: title for the web page, default is 'Documentation'
    :return: html mark up
    """
    base_template = Template("""
    <!DOCTYPE html>
    <html lang="en">
    <head>
    <meta charset="UTF-8">
    <meta name="author" content="aaDoc tool written by Dilli Babu R <dillir07@outlook.com>">
    <meta name="description" content="This page contains documentation, which is auto generated by aaDoc tool
    by using the comments written in Automation Anywhere Code by developers.">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="theme-color" content="#2B65EC">
    <title>$title</title>
    <link rel="stylesheet" href="styles.css">
    </head>
    <body>""")
    return base_template.safe_substitute(title=title)


"""
This file is the source list of all the tags used by aadoc.
This is return a regex pattern by joining all the tags and returning as string.

new tags can be added and old tags can be modified or removed.
Note: Making changes would require changes in other parts of the code as well.
mostly in html_helpers.py file.

Note: Tags are inspired by jsDoc tags at https://jsDoc.app

"""


def generate_tags_for_re() -> str:
    """
    Reads tags list and generates re match pattern
    :return: re-match pattern of tags separated by '|',
                which created by joining tags using join function.
    """

    tags_list = [
        '@author',
        '@date',
        '@constant',
        '@copyright',
        '@default',
        '@deprecated',
        '@description',
        '@file',
        '@function',
        '@global',
        '@ignore',
        '@license',
        '@module',
        '@name',
        '@namespace',
        '@package',
        '@param',
        '@requires',
        '@returns',
        '@see',
        '@since',
        '@summary',
        '@throws',
        '@todo',
        '@type',
        '@version',
    ]
    return '|'.join(tags_list)



"""
This file contains css source that will be written to a css file on the fly when creating
documentation, this data is used by aa_doc.py file.
"""


from string import Template

stylesheet_source_data = Template(
"""

body {
    color: #333;
    font-size: large;
    margin-top: 25px;
    margin-left: 40px !important;
    font-family: 'Courier New', Courier, monospace;
}

div {
    /* color: #2196f3; */
}

.author {
    /* Keep the color else it will default to blue */
    color: #2196f3 !important;
}

.date {
    color: #2196f3;
}

.constant {
    color: #2196f3;
}

.copyright {
    color: #444343;
}

.default {
    color: #2196f3;
}

.deprecated {
    color: #2196f3;
}

.description {
    display: block;
    padding-top: 15px;
    padding-bottom: 15px;
    color: #333;
    width: 75%;
}

.file {
    /* padding-bottom: 10px; */
    display: block;
    margin-top: 10px;
    margin-bottom: 10px;
    font-size: 36px;
    font-style: normal;
    font-weight: bold;
    color: #125e9c;

}

.property-title{
    display: block;
    margin-bottom: 10px;
    margin-top: 10px;
    font-size: 15px;
    font-style: normal;
    font-weight: bold;
    color: #3979ad;
}

.function {
    display: block;
    margin-bottom: 10px;
    margin-top: 10px;
    font-size: 25px;
    font-style: normal;
    font-weight: bold;
    color: #333;
}

.global {
    color: #2196f3;
}

.ignore {
    color: #2196f3;
}

.license {
    color: #2196f3;
}

.module {
    color: #2196f3;
}

.name {
    color: #2196f3;
}

.namespace {
    color: #2196f3;
}

.package {
    color: #2196f3;
}

.param {
    color: #2196f3;
}

.requires {
    color: #2196f3;
}

.returns {
    color: #2196f3;
}

.see {
    color: #2196f3;
}

.since {
    color: #2196f3;
}

.summary {
    color: #2196f3;
}

.throws {
    color: #2196f3;
}

.todo {
    color: #2196f3;
}

.type {
    color: #2196f3;
}

.version {
    color: #2196f3;
}

.label {
    display: block;
    border-left: 2px solid #2196f3;
    padding-left: 15px;
    padding-top: 10px;
    padding-bottom: 10px;
    margin-left: 0px;
    /* 
     * label items should not have margins
     * because we want them to align with each other
     */
    margin-top: 0px !important;
    margin-bottom: 0px !important;
}

table {
    border-collapse: collapse;
    /* width: 100%; */
}

.param-table {
    margin-top: 15px;
    margin-bottom: 15px;
    border: 2px solid #2196f3;
}

.param-header-row {
    background-color: #2196f3;
    color: white;
}

th, td {
    /* border: 0px solid gray;  */
}

.param-table-cell {
    border: 1px solid gray;
    padding: 5px;
}

hr {
    border: none;
    border-top: 3px solid #333;
    color: #333;
    overflow: visible;
    text-align: center;
    height: 5px;
}

.file-link {
    margin-bottom: 10px;
    font-size: 25px;
    font-style: normal;
    font-weight: bold;
    color: #333;
}

.footer {
   position: fixed;
   left: 0;
   bottom: 0;
   width: 100%;
   background-color: #ddd;
   color: gray;
   text-align: center;
}

.footer-content {
   margin-top: 5px;
   margin-bottom: 5px;
}

.header {
    display: block;
    margin-bottom: 10px;
    font-size: 40px;
    font-style: normal;
    font-weight: bold;
    color: #125e9c;
}

.property-title{
    display: block;
    margin-bottom: 10px;
    margin-top: 10px;
    font-size: 20px;
    font-style: normal;
    font-weight: bold;
    color: #333;
}


#aa {
    font-size: inherit;
    color: #333;
    background-color: #2196f3;
    padding: inherit;
}

#doc {
    color: #ddd;
    background-color: #333;
    padding: 3px;
    border-radius: 3px;
}
"""
).safe_substitute()


import setuptools

setuptools.setup(
    name='aadoc',
    version='1.0.1',
    author="Dilli Babu R",
    author_email="dillir07@outlook.com",
    description='A tool that automatically generates documentation from Automation Anywhere comments',
    long_description="",
    long_description_contect_type="text/markdown",
    url="https://dillir07.github.io/aadoc/",
    packages=['aadocmodule', 'aadocmodule.html_helpers_module',
              'aadocmodule.stylesheet_source_module', 'aadocmodule.tags_module'],
    entry_points={
        "console_scripts":['aadoc=aadocmodule.command_line:main']
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
)
